@@ -157,7 +157,13 @@ class CGDB:
              :type time_step_code: str
              :param time_step_code: code of time_step
          """
-
+        if self.element_context_by_element(
+                element_code,
+                aggregation_code,
+                time_step_code,
+                elementMarkOverride) is None:
+            self.create_element_context(element_code, aggregation_code, time_step_code,
+                                               elementMarkOverride)
         self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, data_set_type, elementMarkOverride,)
 
     def create_station(self, name: str, code: str, gpsLatitude: float, gpsLongitude: float, altitude: int, stationNetworkCode, remark=""):
