@@ -1,6 +1,6 @@
 import json
 
-from cgdb.recources.site import Site
+from cgdb.resources.site import Site
 from cgdb.utils.ManagerMix import ManagerMix
 
 
