@@ -1,6 +1,6 @@
 import json
 
-from cgdb.recources.stationGroup import StationGroup
+from cgdb.resources.stationGroup import StationGroup
 from cgdb.utils.ManagerMix import ManagerMix
 
 
